==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp7987_001/MP7987_ReviewWorkSafety_001.java <==

package net.datastream.schemas.mp_functions.mp7987_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ESIGNATURE_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYSAFETYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVIEWEDBYESIGN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Review" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkSafety" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entitysafetycode",
    "reviewedbyesign",
    "entity"
})
@XmlRootElement(name = "MP7987_ReviewWorkSafety_001")
public class MP7987_ReviewWorkSafety_001 {

    @XmlElement(name = "ENTITYSAFETYCODE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entitysafetycode;
    @XmlElement(name = "REVIEWEDBYESIGN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ESIGNATURE_Type reviewedbyesign;
    @XmlElement(name = "ENTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entity;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété entitysafetycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYSAFETYCODE() {
        return entitysafetycode;
    }

    /**
     * Définit la valeur de la propriété entitysafetycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYSAFETYCODE(String value) {
        this.entitysafetycode = value;
    }

    /**
     * Obtient la valeur de la propriété reviewedbyesign.
     * 
     * @return
     *     possible object is
     *     {@link ESIGNATURE_Type }
     *     
     */
    public ESIGNATURE_Type getREVIEWEDBYESIGN() {
        return reviewedbyesign;
    }

    /**
     * Définit la valeur de la propriété reviewedbyesign.
     * 
     * @param value
     *     allowed object is
     *     {@link ESIGNATURE_Type }
     *     
     */
    public void setREVIEWEDBYESIGN(ESIGNATURE_Type value) {
        this.reviewedbyesign = value;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.REVIEW;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_SAFETY;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp7987_001/MP7987_ReviewWorkSafety_001.java <==

package net.datastream.schemas.mp_functions.mp7987_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ESIGNATURE_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ENTITYSAFETYCODE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REVIEWEDBYESIGN"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Review" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkSafety" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entitysafetycode",
    "reviewedbyesign",
    "entity"
})
@XmlRootElement(name = "MP7987_ReviewWorkSafety_001")
public class MP7987_ReviewWorkSafety_001 {

    @XmlElement(name = "ENTITYSAFETYCODE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entitysafetycode;
    @XmlElement(name = "REVIEWEDBYESIGN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ESIGNATURE_Type reviewedbyesign;
    @XmlElement(name = "ENTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entity;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the entitysafetycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYSAFETYCODE() {
        return entitysafetycode;
    }

    /**
     * Sets the value of the entitysafetycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYSAFETYCODE(String value) {
        this.entitysafetycode = value;
    }

    /**
     * Gets the value of the reviewedbyesign property.
     * 
     * @return
     *     possible object is
     *     {@link ESIGNATURE_Type }
     *     
     */
    public ESIGNATURE_Type getREVIEWEDBYESIGN() {
        return reviewedbyesign;
    }

    /**
     * Sets the value of the reviewedbyesign property.
     * 
     * @param value
     *     allowed object is
     *     {@link ESIGNATURE_Type }
     *     
     */
    public void setREVIEWEDBYESIGN(ESIGNATURE_Type value) {
        this.reviewedbyesign = value;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.REVIEW;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_SAFETY;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
